@@ -222,7 +222,10 @@ class Experiment:
         try:
             repo = git.Repo(lab_singleton().path)
 
-            self.run.repo_remotes = list(repo.remote().urls)
+            try:
+                self.run.repo_remotes = list(repo.remote().urls)
+            except (ValueError, git.GitCommandError):
+                self.run.repo_remotes = []
             self.run.commit = repo.head.commit.hexsha
             self.run.commit_message = repo.head.commit.message.strip()
             self.run.is_dirty = repo.is_dirty()
@@ -389,7 +392,7 @@ class Experiment:
                 from labml.internal.api.experiment import ApiExperiment
                 api_caller = ApiCaller(web_api_conf.url,
                                        {'run_uuid': self.run.uuid},
-                                       timeout_seconds=15)
+                                       timeout_seconds=120)
                 self.web_api = ApiExperiment(api_caller,
                                              frequency=web_api_conf.frequency,
                                              open_browser=web_api_conf.open_browser)
