@@ -9,7 +9,10 @@ get_ipython: Callable
 
 
 def yaml_load(s: str):
-    return yaml.load(s, Loader=yaml.FullLoader)
+    if yaml.__version__[0] >= '5':
+        return yaml.load(s, Loader=yaml.FullLoader)
+    else:
+        return yaml.load(s)
 
 
 def yaml_dump(obj: any):
@@ -17,7 +20,9 @@ def yaml_dump(obj: any):
 
 
 def rm_tree(path_to_remove: pathlib.Path):
-    if path_to_remove.is_dir():
+    if path_to_remove.is_symlink():
+        path_to_remove.unlink()
+    elif path_to_remove.is_dir():
         for f in path_to_remove.iterdir():
             if f.is_dir():
                 rm_tree(f)
